@@ -2,12 +2,6 @@ import http.client
 import json
 from typing import TypedDict
 
-PROD_HOST = "engine.pathlit.io"
-weights_path = "/v1/optimiser/weights"
-paths_path = "/v1/optimiser/paths"
-sims_path = "/v1/optimiser/sims"
-
-
 class DataPoint(TypedDict):
     date: str
     value: float
@@ -19,6 +13,13 @@ class TimeSeries(TypedDict):
 
 
 class Client:
+    PROD_HOST = "engine.pathlit.io"
+
+    weights_path = "/v1/optimiser/weights"
+    paths_path = "/v1/optimiser/paths"
+    sims_path = "/v1/optimiser/sims"
+    supported_tickers_path = "/v1/timeseries/info"
+
     """A HTTP client for the PathLit APIs.
 
     :param api_key: your API key obtained from the PathLit dashboard
@@ -32,7 +33,7 @@ class Client:
     """
     def __init__(self, api_key: str):
         self.header = {"x-api-key": api_key}
-        self.host = PROD_HOST
+        self.host = "dev.pathlit.io"
 
     def get_weights(self, tickers: list[str]) -> dict[str, list[float]]:
         """Computes the weights to be allocated for a portfolio, under different strategies. 
@@ -42,7 +43,7 @@ class Client:
         :param tickers: a list of ticker strings
         """
         req_body = json.dumps({"tickers": tickers})
-        s = self.__fetch(weights_path, req_body)
+        s = self.__post(Client.weights_path, req_body)
         res = json.loads(s)
         return res
 
@@ -55,7 +56,7 @@ class Client:
         :param tickers: a list of instrument tickers
         """
         req_body = json.dumps({"tickers": tickers})
-        s = self.__fetch(paths_path, req_body)
+        s = self.__post(Client.paths_path, req_body)
         d = json.loads(s)
 
         return [parse_time_series(dc) for dc in d]
@@ -71,10 +72,24 @@ class Client:
         :param run_count: the number of simulated market data universes. Defaults to 10.
         """
         req_body = json.dumps({"tickers": tickers, "run_count": run_count})
-        resp_body = self.__fetch(sims_path, req_body)
+        resp_body = self.__post(Client.sims_path, req_body)
         return parse_sims(resp_body)
 
-    def __fetch(self, path: str, body: str) -> str:
+    def get_tickers(self) -> list[str]:
+        """Retrieves the list of available tickers.
+        """
+        resp_body = self.__get(Client.supported_tickers_path)
+        return json.loads(resp_body)
+
+
+    def __get(self, path: str) -> str:
+        conn = http.client.HTTPSConnection(self.host)
+        conn.request("GET", path, headers=self.header)
+        s = conn.getresponse().read().decode()
+        conn.close()
+        return s
+
+    def __post(self, path: str, body: str) -> str:
         conn = http.client.HTTPSConnection(self.host)
         conn.request("POST", path, body, headers=self.header)
         s = conn.getresponse().read().decode()
